.. _api_reference:

=============
API reference
=============

Welcome to the API reference for ``skchange``.

The API reference provides a technical manual.
It describes the classes and functions included in skchange.

For Python Interactive examples, see the `interactive <https://github.com/NorskRegnesentral/skchange/tree/main/interactive>`_ folder on Github.

.. toctree::
   :maxdepth: 1

   base
   anomaly_detectors
   anomaly_scores
   change_detectors
   change_scores
   compose
   costs
   datasets
   penalties
   utils
